@@ -1,6 +1,6 @@
 /*
  * ALSA Output Plugin for Audacious
- * Copyright 2009-2010 John Lindgren
+ * Copyright 2009-2012 John Lindgren
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -20,12 +20,13 @@
 #include <alsa/asoundlib.h>
 #include <gtk/gtk.h>
 
-#include <audacious/configdb.h>
 #include <audacious/i18n.h>
+#include <audacious/misc.h>
 #include <libaudgui/libaudgui.h>
 #include <libaudgui/libaudgui-gtk.h>
 
 #include "alsa.h"
+#include "config.h"
 
 char * alsa_config_pcm = NULL, * alsa_config_mixer = NULL,
  * alsa_config_mixer_element = NULL;
@@ -33,7 +34,7 @@ int alsa_config_drain_workaround = 1;
 
 static GtkListStore * pcm_list, * mixer_list, * mixer_element_list;
 static GtkWidget * window, * pcm_combo, * mixer_combo, * mixer_element_combo,
- * ok_button, * drain_workaround_check;
+ * drain_workaround_check;
 
 static GtkTreeIter * list_lookup_member (GtkListStore * list, const char * text)
 {
@@ -69,7 +70,6 @@ static int list_has_member (GtkListStore * list, const char * text)
 static void get_defined_devices (const char * type, int capture, void (* found)
  (const char * name, const char * description))
 {
-#ifdef HAVE_SND_DEVICE_NAME_HINT
     void * * hints = NULL;
     int count;
 
@@ -95,7 +95,6 @@ static void get_defined_devices (const char * type, int capture, void (* found)
 FAILED:
     if (hints != NULL)
         snd_device_name_free_hint (hints);
-#endif
 }
 
 static char * get_card_description (int card)
@@ -277,24 +276,37 @@ static void mixer_element_list_fill (void)
     get_mixer_elements (alsa_config_mixer, mixer_element_found);
 }
 
-static void guess_mixer_element (void)
+static void fill_lists (void)
 {
-    static const char * guesses[] = {"PCM", "Wave", "Master"};
-    int count;
-
-    if (alsa_config_mixer_element != NULL)
+    if (! pcm_list)
     {
-        if (list_has_member (mixer_element_list, alsa_config_mixer_element))
-            return;
-
-        free (alsa_config_mixer_element);
-        alsa_config_mixer_element = NULL;
+        pcm_list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+        pcm_list_fill ();
     }
 
-    for (count = 0; count < G_N_ELEMENTS (guesses); count ++)
+    if (! mixer_list)
+    {
+        mixer_list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+        mixer_list_fill ();
+    }
+
+    if (! mixer_element_list)
+    {
+        mixer_element_list = gtk_list_store_new (1, G_TYPE_STRING);
+        mixer_element_list_fill ();
+    }
+}
+
+static void guess_mixer_element (void)
+{
+    fill_lists ();
+
+    static const char * guesses[] = {"Master", "PCM", "Wave"};
+    for (int count = 0; count < G_N_ELEMENTS (guesses); count ++)
     {
         if (list_has_member (mixer_element_list, guesses[count]))
         {
+            free (alsa_config_mixer_element);
             alsa_config_mixer_element = strdup (guesses[count]);
             return;
         }
@@ -303,70 +315,56 @@ static void guess_mixer_element (void)
     ERROR_NOISY ("No suitable mixer element found.\n");
 }
 
+static const gchar * const alsa_defaults[] = {
+ "pcm", "default",
+ "mixer", "default",
+ "drain-workaround", "TRUE",
+ NULL};
+
 void alsa_config_load (void)
 {
-    mcs_handle_t * database = aud_cfg_db_open ();
+    aud_config_set_defaults ("alsa", alsa_defaults);
 
-    pcm_list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
-    mixer_list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
-    mixer_element_list = gtk_list_store_new (1, G_TYPE_STRING);
+    alsa_config_pcm = aud_get_string ("alsa", "pcm");
+    alsa_config_mixer = aud_get_string ("alsa", "mixer");
+    alsa_config_mixer_element = aud_get_string ("alsa", "mixer-element");
+    alsa_config_drain_workaround = aud_get_bool ("alsa", "drain-workaround");
 
-    pcm_list_fill ();
-    aud_cfg_db_get_string (database, "alsa", "pcm", & alsa_config_pcm);
-
-    if (alsa_config_pcm == NULL)
-        alsa_config_pcm = strdup ("default");
-    else if (strcmp (alsa_config_pcm, "default") && ! list_has_member (pcm_list,
-     alsa_config_pcm))
-    {
-        free (alsa_config_pcm);
-        alsa_config_pcm = strdup ("default");
-    }
-
-    mixer_list_fill ();
-    aud_cfg_db_get_string (database, "alsa", "mixer",
-     & alsa_config_mixer);
-
-    if (alsa_config_mixer == NULL)
-        alsa_config_mixer = strdup ("default");
-    else if (strcmp (alsa_config_mixer, "default") && ! list_has_member
-     (mixer_list, alsa_config_mixer))
-    {
-        free (alsa_config_mixer);
-        alsa_config_mixer = strdup ("default");
-    }
-
-    mixer_element_list_fill ();
-    aud_cfg_db_get_string (database, "alsa", "mixer-element",
-     & alsa_config_mixer_element);
-    guess_mixer_element ();
-
-    aud_cfg_db_get_bool (database, "alsa", "drain-workaround", &
-     alsa_config_drain_workaround);
-
-    aud_cfg_db_close (database);
+    if (! alsa_config_mixer_element[0])
+        guess_mixer_element ();
 }
 
 void alsa_config_save (void)
 {
-    mcs_handle_t * database = aud_cfg_db_open ();
+    if (pcm_list)
+    {
+        g_object_unref (pcm_list);
+        pcm_list = NULL;
+    }
 
-    g_object_unref (pcm_list);
-    g_object_unref (mixer_list);
-    g_object_unref (mixer_element_list);
+    if (mixer_list)
+    {
+        g_object_unref (mixer_list);
+        mixer_list = NULL;
+    }
 
-    aud_cfg_db_set_string (database, "alsa", "pcm", alsa_config_pcm);
-    aud_cfg_db_set_string (database, "alsa", "mixer", alsa_config_mixer);
-    aud_cfg_db_set_string (database, "alsa", "mixer-element",
-     alsa_config_mixer_element);
-    aud_cfg_db_set_bool (database, "alsa", "drain-workaround",
-     alsa_config_drain_workaround);
+    if (mixer_element_list)
+    {
+        g_object_unref (mixer_element_list);
+        mixer_element_list = NULL;
+    }
+
+    aud_set_string ("alsa", "pcm", alsa_config_pcm);
+    aud_set_string ("alsa", "mixer", alsa_config_mixer);
+    aud_set_string ("alsa", "mixer-element", alsa_config_mixer_element);
+    aud_set_bool ("alsa", "drain-workaround", alsa_config_drain_workaround);
 
     free (alsa_config_pcm);
+    alsa_config_pcm = NULL;
     free (alsa_config_mixer);
+    alsa_config_mixer = NULL;
     free (alsa_config_mixer_element);
-
-    aud_cfg_db_close (database);
+    alsa_config_mixer_element = NULL;
 }
 
 static GtkWidget * combo_new (const char * title, GtkListStore * list,
@@ -375,7 +373,7 @@ static GtkWidget * combo_new (const char * title, GtkListStore * list,
     GtkWidget * hbox, * label;
     GtkCellRenderer * cell;
 
-    hbox = gtk_hbox_new (0, 6);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 
     label = gtk_label_new (title);
     gtk_box_pack_start ((GtkBox *) hbox, label, 0, 0, 0);
@@ -432,17 +430,11 @@ static const char * combo_selected_text (GtkWidget * combo, GtkListStore * list)
 
 static void create_window (void)
 {
-    GtkWidget * vbox, * hbox;
-
-    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_type_hint ((GtkWindow *) window, GDK_WINDOW_TYPE_HINT_DIALOG);
+    window = gtk_dialog_new_with_buttons (_("ALSA Output Plugin Preferences"),
+     NULL, 0, GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
     gtk_window_set_resizable ((GtkWindow *) window, 0);
-    gtk_window_set_title ((GtkWindow *) window, _("ALSA Output Plugin "
-     "Preferences"));
-    gtk_container_set_border_width ((GtkContainer *) window, 6);
 
-    vbox = gtk_vbox_new (0, 6);
-    gtk_container_add ((GtkContainer *) window, vbox);
+    GtkWidget * vbox = gtk_dialog_get_content_area ((GtkDialog *) window);
 
     gtk_box_pack_start ((GtkBox *) vbox, combo_new (_("PCM device:"), pcm_list,
      & pcm_combo, 1), 0, 0, 0);
@@ -457,12 +449,6 @@ static void create_window (void)
      alsa_config_drain_workaround);
     gtk_box_pack_start ((GtkBox *) vbox, drain_workaround_check, 0, 0, 0);
 
-    hbox = gtk_hbox_new (0, 6);
-    gtk_box_pack_start ((GtkBox *) vbox, hbox, 0, 0, 0);
-
-    ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-    gtk_box_pack_end ((GtkBox *) hbox, ok_button, 0, 0, 0);
-
     gtk_widget_show_all (window);
 }
 
@@ -475,6 +461,8 @@ static void pcm_changed (GtkComboBox * combo, void * unused)
 
     free (alsa_config_pcm);
     alsa_config_pcm = strdup (combo_selected_text (pcm_combo, pcm_list));
+
+    aud_output_reset (OUTPUT_RESET_SOFT);
 }
 
 static void mixer_changed (GtkComboBox * combo, void * unused)
@@ -528,7 +516,7 @@ static void connect_callbacks (void)
      mixer_element_changed, NULL);
     g_signal_connect ((GObject *) drain_workaround_check, "toggled", (GCallback)
      boolean_toggled, & alsa_config_drain_workaround);
-    g_signal_connect_swapped ((GObject *) ok_button, "clicked", (GCallback)
+    g_signal_connect ((GObject *) window, "response", (GCallback)
      gtk_widget_destroy, window);
     g_signal_connect ((GObject *) window, "destroy", (GCallback)
      gtk_widget_destroyed, & window);
@@ -546,6 +534,7 @@ void alsa_configure (void)
         return;
     }
 
+    fill_lists ();
     create_window ();
     combo_select_by_text (pcm_combo, pcm_list, alsa_config_pcm);
     combo_select_by_text (mixer_combo, mixer_list, alsa_config_mixer);
