@@ -18,6 +18,8 @@
 *
 */
 
+#include <pthread.h>
+
 #include <audacious/drct.h>
 #include <audacious/misc.h>
 #include <audacious/plugin.h>
@@ -55,62 +57,44 @@ AUD_INPUT_PLUGIN
     .extensions = amidiplug_vfs_extensions,
 )
 
-static GMutex * init_mutex;
-static gboolean initted;
+static pthread_mutex_t control_mutex = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t control_cond = PTHREAD_COND_INITIALIZER;
+static pthread_mutex_t audio_control_mutex = PTHREAD_MUTEX_INITIALIZER;
 
-static GCond * control_cond;
+static gboolean initted;
 static gint seek_time;
 
-static GThread * audio_thread;
-static GMutex * audio_control_mutex;
-static GCond * audio_control_cond;
-static gboolean audio_stop_flag, audio_pause_flag;
+static pthread_t audio_thread;
+static gboolean audio_stop_flag;
 static gint audio_seek_time;
 
+static volatile gint current_time = -1;
+
 static gboolean amidiplug_init (void)
 {
-    init_mutex = g_mutex_new ();
     initted = FALSE;
     return TRUE;
 }
 
 static void soft_init (void)
 {
-    g_mutex_lock (init_mutex);
+    pthread_mutex_lock (& control_mutex);
 
     if (! initted)
     {
-        amidiplug_gettime_mutex = g_mutex_new ();
-        amidiplug_playing_mutex = g_mutex_new ();
-        control_cond = g_cond_new ();
-
-        audio_control_mutex = g_mutex_new ();
-        audio_control_cond = g_cond_new ();
-
         i_configure_cfg_ap_read ();
         i_backend_load (amidiplug_cfg_ap.ap_seq_backend);
 
         initted = TRUE;
     }
 
-    g_mutex_unlock (init_mutex);
+    pthread_mutex_unlock (& control_mutex);
 }
 
 static void amidiplug_cleanup (void)
 {
     if (initted)
-    {
         i_backend_unload ();
-
-        g_mutex_free (amidiplug_gettime_mutex);
-        g_mutex_free (amidiplug_playing_mutex);
-        g_cond_free (control_cond);
-
-        g_mutex_free (audio_control_mutex);
-        g_cond_free (audio_control_cond);
-    }
-
-    g_mutex_free (init_mutex);
 }
 
 static gint amidiplug_is_our_file_from_vfs( const gchar *filename_uri , VFSFile *fp )
@@ -175,74 +159,33 @@ static void amidiplug_stop( InputPlayback * playback )
 {
   DEBUGMSG( "STOP request at tick: %i\n" , midifile.playing_tick );
 
-  g_mutex_lock( amidiplug_playing_mutex );
+  pthread_mutex_lock (& control_mutex);
   amidiplug_playing_status = AMIDIPLUG_STOP;
-  g_cond_signal (control_cond);
-  g_mutex_unlock( amidiplug_playing_mutex );
+  pthread_cond_broadcast (& control_cond);
+  pthread_mutex_unlock (& control_mutex);
 }
 
 static void amidiplug_pause (InputPlayback * playback, gboolean paused)
 {
-    g_mutex_lock (amidiplug_playing_mutex);
+    pthread_mutex_lock (& control_mutex);
     amidiplug_playing_status = paused ? AMIDIPLUG_PAUSE : AMIDIPLUG_PLAY;
-    g_cond_signal (control_cond);
-    g_cond_wait (control_cond, amidiplug_playing_mutex);
-    g_mutex_unlock (amidiplug_playing_mutex);
+    pthread_cond_broadcast (& control_cond);
+    pthread_mutex_unlock (& control_mutex);
 }
 
 static void amidiplug_mseek (InputPlayback * playback, gint time)
 {
-    g_mutex_lock (amidiplug_playing_mutex);
-    amidiplug_playing_status = AMIDIPLUG_SEEK;
+    pthread_mutex_lock (& control_mutex);
     seek_time = time;
-    g_cond_signal (control_cond);
-    g_cond_wait (control_cond, amidiplug_playing_mutex);
-    g_mutex_unlock (amidiplug_playing_mutex);
+    pthread_cond_broadcast (& control_cond);
+    pthread_mutex_unlock (& control_mutex);
 }
 
-static gint amidiplug_get_time( InputPlayback * playback )
+static gint amidiplug_get_time (InputPlayback * playback)
 {
-    gint pt;
-
-    if (! backend.autonomous_audio)
-        return -1;
-
-    g_mutex_lock (amidiplug_playing_mutex);
-
-    if (seek_time != -1)
-    {
-        gint time = seek_time;
-
-        g_mutex_unlock (amidiplug_playing_mutex);
-        return time;
-    }
-
-    if (( amidiplug_playing_status == AMIDIPLUG_PLAY ) ||
-        ( amidiplug_playing_status == AMIDIPLUG_PAUSE ) ||
-        ( amidiplug_playing_status == AMIDIPLUG_SEEK ))
-    {
-      g_mutex_unlock( amidiplug_playing_mutex );
-      g_mutex_lock( amidiplug_gettime_mutex );
-      pt = midifile.playing_tick;
-      g_mutex_unlock( amidiplug_gettime_mutex );
-      return (gint)((pt * midifile.avg_microsec_per_tick) / 1000);
-    }
-    else if ( amidiplug_playing_status == AMIDIPLUG_STOP )
-    {
-      g_mutex_unlock( amidiplug_playing_mutex );
-      DEBUGMSG( "GETTIME on stopped song, returning -1\n" );
-      return -1;
-    }
-    else /* AMIDIPLUG_ERR */
-    {
-      g_mutex_unlock( amidiplug_playing_mutex );
-      DEBUGMSG( "GETTIME on halted song (an error occurred?), returning -1 and stopping the player\n" );
-      aud_drct_stop();
-      return -1;
-    }
+    return current_time;
 }
 
-
 static gint amidiplug_get_volume( gint * l_p , gint * r_p )
 {
   if ( backend.autonomous_audio == TRUE )
@@ -390,11 +333,8 @@ static gboolean amidiplug_play (InputPlayback * playback, const gchar *
 
       /* play play play! */
       DEBUGMSG( "PLAY requested, starting play thread\n" );
-      g_mutex_lock( amidiplug_playing_mutex );
-      amidiplug_playing_status = AMIDIPLUG_PLAY;
-      g_mutex_unlock( amidiplug_playing_mutex );
-
-      seek_time = -1;
+      amidiplug_playing_status = pause ? AMIDIPLUG_PAUSE : AMIDIPLUG_PLAY;
+      seek_time = (start_time > 0) ? start_time : -1;
       playback->set_pb_ready(playback);
       amidiplug_play_loop(playback);
       break;
@@ -414,18 +354,16 @@ static gboolean amidiplug_play (InputPlayback * playback, const gchar *
 static void * audio_loop (void * arg)
 {
     InputPlayback * playback = arg;
-    gboolean paused = FALSE;
     void * buffer = NULL;
     gint buffer_size = 0;
 
     while (1)
     {
-        g_mutex_lock (audio_control_mutex);
+        pthread_mutex_lock (& audio_control_mutex);
 
         if (audio_stop_flag)
         {
-            g_cond_signal (audio_control_cond);
-            g_mutex_unlock (audio_control_mutex);
+            pthread_mutex_unlock (& audio_control_mutex);
             break;
         }
 
@@ -433,31 +371,9 @@ static void * audio_loop (void * arg)
         {
             playback->output->flush (audio_seek_time);
             audio_seek_time = -1;
-            g_cond_signal (audio_control_cond);
         }
 
-        if (audio_pause_flag)
-        {
-            if (! paused)
-            {
-                playback->output->pause (TRUE);
-                paused = TRUE;
-            }
-
-            g_cond_signal (audio_control_cond);
-            g_cond_wait (audio_control_cond, audio_control_mutex);
-            g_mutex_unlock (audio_control_mutex);
-            continue;
-        }
-
-        if (paused)
-        {
-            playback->output->pause (FALSE);
-            paused = FALSE;
-            g_cond_signal (audio_control_cond);
-        }
-
-        g_mutex_unlock (audio_control_mutex);
+        pthread_mutex_unlock (& audio_control_mutex);
 
         if (backend.seq_output (& buffer, & buffer_size))
             playback->output->write_audio (buffer, buffer_size);
@@ -470,36 +386,30 @@ static void * audio_loop (void * arg)
 static void audio_start (InputPlayback * playback)
 {
     audio_stop_flag = FALSE;
-    audio_pause_flag = FALSE;
     audio_seek_time = -1;
-    audio_thread = g_thread_create (audio_loop, (void *) playback, TRUE, NULL);
+    pthread_create (& audio_thread, NULL, audio_loop, (void *) playback);
 }
 
-static void audio_seek (gint time)
+static void audio_seek (InputPlayback * playback, gint time)
 {
-    g_mutex_lock (audio_control_mutex);
+    pthread_mutex_lock (& audio_control_mutex);
     audio_seek_time = time;
-    g_cond_signal (audio_control_cond);
-    g_cond_wait (audio_control_cond, audio_control_mutex);
-    g_mutex_unlock (audio_control_mutex);
+    playback->output->abort_write ();
+    pthread_mutex_unlock (& audio_control_mutex);
 }
 
-static void audio_pause (gboolean pause)
+static void audio_pause (InputPlayback * playback, gboolean pause)
 {
-    g_mutex_lock (audio_control_mutex);
-    audio_pause_flag = pause;
-    g_cond_signal (audio_control_cond);
-    g_cond_wait (audio_control_cond, audio_control_mutex);
-    g_mutex_unlock (audio_control_mutex);
+    playback->output->pause (pause);
 }
 
-static void audio_stop (void)
+static void audio_stop (InputPlayback * playback)
 {
-    g_mutex_lock (audio_control_mutex);
+    pthread_mutex_lock (& audio_control_mutex);
     audio_stop_flag = TRUE;
-    g_cond_signal (audio_control_cond);
-    g_mutex_unlock (audio_control_mutex);
-    g_thread_join (audio_thread);
+    playback->output->abort_write ();
+    pthread_mutex_unlock (& audio_control_mutex);
+    pthread_join (audio_thread, NULL);
 }
 
 static void do_seek (gint time)
@@ -550,29 +460,22 @@ static void amidiplug_play_loop (InputPlayback * playback)
     midifile_track_t * event_track = NULL;
     gint i, min_tick = midifile.max_tick + 1;
 
-    g_mutex_lock (amidiplug_playing_mutex);
+    pthread_mutex_lock (& control_mutex);
 
     if (amidiplug_playing_status == AMIDIPLUG_STOP)
     {
-        g_mutex_unlock (amidiplug_playing_mutex);
+        pthread_mutex_unlock (& control_mutex);
         stopped = TRUE;
         break;
     }
 
-    if (amidiplug_playing_status == AMIDIPLUG_SEEK)
+    if (seek_time != -1)
     {
         if (! backend.autonomous_audio)
-            audio_seek (seek_time);
+            audio_seek (playback, seek_time);
 
-        /* WORKAROUND: wait till unpause to seek */
-        if (! paused)
-        {
-            do_seek (seek_time);
-            seek_time = -1;
-        }
-
-        amidiplug_playing_status = paused ? AMIDIPLUG_PAUSE : AMIDIPLUG_PLAY;
-        g_cond_signal (control_cond);
+        do_seek (seek_time);
+        seek_time = -1;
     }
 
     if (amidiplug_playing_status == AMIDIPLUG_PAUSE)
@@ -582,14 +485,13 @@ static void amidiplug_play_loop (InputPlayback * playback)
             do_pause (TRUE);
 
             if (! backend.autonomous_audio)
-                audio_pause (TRUE);
+                audio_pause (playback, TRUE);
 
             paused = TRUE;
-            g_cond_signal (control_cond);
         }
 
-        g_cond_wait (control_cond, amidiplug_playing_mutex);
-        g_mutex_unlock (amidiplug_playing_mutex);
+        pthread_cond_wait (& control_cond, & control_mutex);
+        pthread_mutex_unlock (& control_mutex);
         continue;
     }
 
@@ -598,20 +500,12 @@ static void amidiplug_play_loop (InputPlayback * playback)
         do_pause (FALSE);
 
         if (! backend.autonomous_audio)
-            audio_pause (FALSE);
-
-        /* WORKAROUND (see above) */
-        if (seek_time != -1)
-        {
-            do_seek (seek_time);
-            seek_time = -1;
-        }
+            audio_pause (playback, FALSE);
 
         paused = FALSE;
-        g_cond_signal (control_cond);
     }
 
-    g_mutex_unlock (amidiplug_playing_mutex);
+    pthread_mutex_unlock (& control_mutex);
 
     /* search next event */
     for (i = 0; i < midifile.num_tracks; ++i)
@@ -665,9 +559,7 @@ static void amidiplug_play_loop (InputPlayback * playback)
         backend.seq_event_tempo( event );
         DEBUGMSG( "PLAY thread, processing tempo event with value %i on tick %i\n" ,
                   event->data.tempo , event->tick );
-        g_mutex_lock( amidiplug_gettime_mutex );
         midifile.current_tempo = event->data.tempo;
-        g_mutex_unlock( amidiplug_gettime_mutex );
         break;
       case SND_SEQ_EVENT_META_TEXT:
         /* do nothing */
@@ -680,12 +572,13 @@ static void amidiplug_play_loop (InputPlayback * playback)
         break;
     }
 
-    g_mutex_lock( amidiplug_gettime_mutex );
     midifile.playing_tick = event->tick;
-    g_mutex_unlock( amidiplug_gettime_mutex );
 
-    if ( backend.autonomous_audio == TRUE )
+    if (backend.autonomous_audio)
     {
+      current_time = (gint64) midifile.playing_tick *
+       midifile.avg_microsec_per_tick / 1000;
+
       /* these backends deal with audio production themselves (i.e. ALSA) */
       backend.seq_output( NULL , NULL );
     }
@@ -695,11 +588,13 @@ static void amidiplug_play_loop (InputPlayback * playback)
    midifile.skip_offset);
 
   if (! backend.autonomous_audio)
-      audio_stop ();
+      audio_stop (playback);
 
   backend.seq_off ();
   backend.seq_stop ();
   i_midi_free (& midifile);
+
+  current_time = -1;
 }
 
 
@@ -788,9 +683,7 @@ void amidiplug_skipto( gint playing_tick )
         break;
       case SND_SEQ_EVENT_TEMPO:
         backend.seq_event_tempo( event );
-        g_mutex_lock( amidiplug_gettime_mutex );
         midifile.current_tempo = event->data.tempo;
-        g_mutex_unlock( amidiplug_gettime_mutex );
         break;
     }
 
@@ -802,6 +695,5 @@ void amidiplug_skipto( gint playing_tick )
   }
 
   midifile.skip_offset = playing_tick;
-
-  return;
+  midifile.playing_tick = playing_tick;
 }
