@@ -18,12 +18,15 @@
 *
 */
 
+#include <glib/gstdio.h>
+#include <gtk/gtk.h>
 
 #include "i_configure-fluidsynth.h"
+
+#ifdef AMIDIPLUG_FLUIDSYNTH
+
 #include "backend-fluidsynth/b-fluidsynth-config.h"
 #include "backend-fluidsynth/backend-fluidsynth-icon.xpm"
-#include <glib/gstdio.h>
-
 
 enum
 {
@@ -45,7 +48,7 @@ void i_configure_ev_toggle_default( GtkToggleButton *togglebutton , gpointer hbo
 void i_configure_ev_sflist_add( gpointer sfont_lv )
 {
   GtkWidget *parent_window = gtk_widget_get_toplevel( sfont_lv );
-  if ( GTK_WIDGET_TOPLEVEL(parent_window) )
+  if (gtk_widget_is_toplevel (parent_window))
   {
     GtkTreeSelection *listsel = gtk_tree_view_get_selection( GTK_TREE_VIEW(sfont_lv) );
     GtkTreeIter itersel, iterapp;
@@ -171,7 +174,7 @@ void i_configure_ev_sfload_commit( gpointer sfload_radiobt )
 void i_configure_ev_sygain_commit( gpointer gain_spinbt )
 {
   amidiplug_cfg_fsyn_t * fsyncfg = amidiplug_cfg_backend->fsyn;
-  if ( GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(gain_spinbt)) )
+  if (gtk_widget_get_sensitive (gain_spinbt))
     fsyncfg->fsyn_synth_gain = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(gain_spinbt)) * 10);
   else
     fsyncfg->fsyn_synth_gain = -1;
@@ -181,17 +184,17 @@ void i_configure_ev_sygain_commit( gpointer gain_spinbt )
 void i_configure_ev_sypoly_commit( gpointer poly_spinbt )
 {
   amidiplug_cfg_fsyn_t * fsyncfg = amidiplug_cfg_backend->fsyn;
-  if ( GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(poly_spinbt)) )
-    fsyncfg->fsyn_synth_poliphony = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(poly_spinbt)));
+  if (gtk_widget_get_sensitive (poly_spinbt))
+    fsyncfg->fsyn_synth_polyphony = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(poly_spinbt)));
   else
-    fsyncfg->fsyn_synth_poliphony = -1;
+    fsyncfg->fsyn_synth_polyphony = -1;
 }
 
 
 void i_configure_ev_syreverb_commit( gpointer reverb_yes_radiobt )
 {
   amidiplug_cfg_fsyn_t * fsyncfg = amidiplug_cfg_backend->fsyn;
-  if ( GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(reverb_yes_radiobt)) )
+  if (gtk_widget_get_sensitive (reverb_yes_radiobt))
   {
     if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(reverb_yes_radiobt) ) )
       fsyncfg->fsyn_synth_reverb = 1;
@@ -206,7 +209,7 @@ void i_configure_ev_syreverb_commit( gpointer reverb_yes_radiobt )
 void i_configure_ev_sychorus_commit( gpointer chorus_yes_radiobt )
 {
   amidiplug_cfg_fsyn_t * fsyncfg = amidiplug_cfg_backend->fsyn;
-  if ( GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET(chorus_yes_radiobt)) )
+  if (gtk_widget_get_sensitive (chorus_yes_radiobt))
   {
     if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(chorus_yes_radiobt) ) )
       fsyncfg->fsyn_synth_chorus = 1;
@@ -256,44 +259,19 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
                                gpointer backend_list_p ,
                                gpointer commit_button )
 {
-  GtkWidget *fsyn_page_vbox;
-  GtkWidget *title_widget;
-  GtkWidget *content_vbox; /* this vbox will contain the various frames for config sections */
-  GSList * backend_list = backend_list_p;
-  gboolean fsyn_module_ok = FALSE;
-  gchar * fsyn_module_pathfilename;
+  GtkWidget * content_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
 
-  fsyn_page_vbox = gtk_vbox_new( FALSE , 0 );
-
-  title_widget = i_configure_gui_draw_title( _("FLUIDSYNTH BACKEND CONFIGURATION") );
-  gtk_box_pack_start( GTK_BOX(fsyn_page_vbox) , title_widget , FALSE , FALSE , 2 );
-
-  content_vbox = gtk_vbox_new( FALSE , 2 );
-
-  /* check if the FluidSynth module is available */
-  while ( backend_list != NULL )
-  {
-    amidiplug_sequencer_backend_name_t * mn = backend_list->data;
-    if ( !strcmp( mn->name , "fluidsynth" ) )
-    {
-      fsyn_module_ok = TRUE;
-      fsyn_module_pathfilename = mn->filename;
-      break;
-    }
-    backend_list = backend_list->next;
-  }
-
-  if ( fsyn_module_ok )
+  if (1)
   {
     GtkWidget *soundfont_frame, *soundfont_vbox;
     GtkListStore *soundfont_file_store;
     GtkCellRenderer *soundfont_file_lv_text_rndr;
     GtkTreeViewColumn *soundfont_file_lv_fname_col, *soundfont_file_lv_fsize_col;
-    GtkWidget *soundfont_file_hbox, *soundfont_file_lv, *soundfont_file_lv_sw, *soundfont_file_lv_frame;
+    GtkWidget *soundfont_file_hbox, *soundfont_file_lv, *soundfont_file_lv_sw;
     GtkTreeSelection *soundfont_file_lv_sel;
     GtkWidget *soundfont_file_bbox_vbox, *soundfont_file_bbox_addbt, *soundfont_file_bbox_rembt;
     GtkWidget *soundfont_file_bbox_mvupbt, *soundfont_file_bbox_mvdownbt;
-    GtkWidget *soundfont_load_hsep, *soundfont_load_hbox, *soundfont_load_option[2];
+    GtkWidget *soundfont_load_hbox, *soundfont_load_option[2];
     GtkWidget *synth_frame, *synth_hbox, *synth_leftcol_vbox, *synth_rightcol_vbox;
     GtkWidget *synth_samplerate_frame, *synth_samplerate_vbox, *synth_samplerate_option[4];
     GtkWidget *synth_samplerate_optionhbox, *synth_samplerate_optionentry, *synth_samplerate_optionlabel;
@@ -305,16 +283,12 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     GtkWidget *synth_reverb_value_option[2], *synth_reverb_defcheckbt;
     GtkWidget *synth_chorus_frame, *synth_chorus_hbox, *synth_chorus_value_hbox;
     GtkWidget *synth_chorus_value_option[2], *synth_chorus_defcheckbt;
-    GtkTooltips *tips;
 
     amidiplug_cfg_fsyn_t * fsyncfg = amidiplug_cfg_backend->fsyn;
 
-    tips = gtk_tooltips_new();
-    g_object_set_data_full( G_OBJECT(fsyn_page_alignment) , "tt" , tips , g_object_unref );
-
     /* soundfont settings */
     soundfont_frame = gtk_frame_new( _("SoundFont settings") );
-    soundfont_vbox = gtk_vbox_new( FALSE , 2 );
+    soundfont_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2 );
     gtk_container_set_border_width( GTK_CONTAINER(soundfont_vbox), 4 );
     gtk_container_add( GTK_CONTAINER(soundfont_frame) , soundfont_vbox );
     /* soundfont settings - soundfont files - listview */
@@ -339,7 +313,7 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
       }
       g_strfreev( sffiles );
     }
-    soundfont_file_hbox = gtk_hbox_new( FALSE , 2 );
+    soundfont_file_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2 );
     soundfont_file_lv = gtk_tree_view_new_with_model( GTK_TREE_MODEL(soundfont_file_store) );
     gtk_tree_view_set_rules_hint( GTK_TREE_VIEW(soundfont_file_lv), TRUE );
     g_object_unref( soundfont_file_store );
@@ -356,14 +330,15 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     gtk_tree_view_append_column( GTK_TREE_VIEW(soundfont_file_lv), soundfont_file_lv_fsize_col );
     soundfont_file_lv_sel = gtk_tree_view_get_selection( GTK_TREE_VIEW(soundfont_file_lv) );
     gtk_tree_selection_set_mode( GTK_TREE_SELECTION(soundfont_file_lv_sel) , GTK_SELECTION_SINGLE );
+
     soundfont_file_lv_sw = gtk_scrolled_window_new( NULL , NULL );
-    gtk_scrolled_window_set_policy( GTK_SCROLLED_WINDOW(soundfont_file_lv_sw) ,
-                                    GTK_POLICY_NEVER , GTK_POLICY_ALWAYS );
-    soundfont_file_lv_frame = gtk_frame_new( NULL );
+    gtk_scrolled_window_set_shadow_type ((GtkScrolledWindow *) soundfont_file_lv_sw, GTK_SHADOW_IN);
+    gtk_scrolled_window_set_policy ((GtkScrolledWindow *) soundfont_file_lv_sw,
+     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add( GTK_CONTAINER(soundfont_file_lv_sw) , soundfont_file_lv );
-    gtk_container_add( GTK_CONTAINER(soundfont_file_lv_frame) , soundfont_file_lv_sw );
+
     /* soundfont settings - soundfont files - buttonbox */
-    soundfont_file_bbox_vbox = gtk_vbox_new( TRUE , 0 );
+    soundfont_file_bbox_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0 );
     soundfont_file_bbox_addbt = gtk_button_new();
     gtk_button_set_image( GTK_BUTTON(soundfont_file_bbox_addbt) ,
                           gtk_image_new_from_stock( GTK_STOCK_ADD , GTK_ICON_SIZE_MENU ) );
@@ -390,51 +365,48 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     g_signal_connect( G_OBJECT(soundfont_file_bbox_mvdownbt) , "clicked" ,
                       G_CALLBACK(i_configure_ev_sflist_swap) , soundfont_file_lv );
     gtk_box_pack_start( GTK_BOX(soundfont_file_bbox_vbox) , soundfont_file_bbox_mvdownbt , FALSE , FALSE , 0 );
-    gtk_box_pack_start( GTK_BOX(soundfont_file_hbox) , soundfont_file_lv_frame , TRUE , TRUE , 0 );
+    gtk_box_pack_start( GTK_BOX(soundfont_file_hbox) , soundfont_file_lv_sw , TRUE , TRUE , 0 );
     gtk_box_pack_start( GTK_BOX(soundfont_file_hbox) , soundfont_file_bbox_vbox , FALSE , FALSE , 0 );
     gtk_box_pack_start( GTK_BOX(soundfont_vbox) , soundfont_file_hbox , FALSE , FALSE , 0 );
 
     /* soundfont settings - load */
-    soundfont_load_hsep = gtk_hseparator_new();
-    soundfont_load_hbox = gtk_hbox_new( FALSE , 0 );
+    soundfont_load_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
     soundfont_load_option[0] = gtk_radio_button_new_with_label( NULL ,
                                  _("Load SF on player start") );
     g_object_set_data( G_OBJECT(soundfont_load_option[0]) , "val" , GINT_TO_POINTER(0) );
     soundfont_load_option[1] = gtk_radio_button_new_with_label_from_widget(
                                  GTK_RADIO_BUTTON(soundfont_load_option[0]) ,
-                                 _("Load SF on first midifile play") );
+                                 _("Load SF on first MIDI file play") );
     g_object_set_data( G_OBJECT(soundfont_load_option[1]) , "val" , GINT_TO_POINTER(1) );
     if ( fsyncfg->fsyn_soundfont_load == 0 )
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(soundfont_load_option[0]) , TRUE );
     else
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(soundfont_load_option[1]) , TRUE );
     gtk_box_pack_start( GTK_BOX(soundfont_load_hbox) , soundfont_load_option[0] , TRUE , TRUE , 0 );
-    gtk_box_pack_start( GTK_BOX(soundfont_load_hbox) , gtk_vseparator_new() , FALSE , FALSE , 4 );
     gtk_box_pack_start( GTK_BOX(soundfont_load_hbox) , soundfont_load_option[1] , TRUE , TRUE , 0 );
-    gtk_box_pack_start( GTK_BOX(soundfont_vbox) , soundfont_load_hsep , FALSE , FALSE , 3 );
     gtk_box_pack_start( GTK_BOX(soundfont_vbox) , soundfont_load_hbox , FALSE , FALSE , 0 );
 
     gtk_box_pack_start( GTK_BOX(content_vbox) , soundfont_frame , FALSE , FALSE , 0 );
 
     /* synth settings */
     synth_frame = gtk_frame_new( _("Synthesizer settings") );
-    synth_hbox = gtk_hbox_new( FALSE , 4 );
+    synth_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4 );
     gtk_container_set_border_width( GTK_CONTAINER(synth_hbox), 4 );
     gtk_container_add( GTK_CONTAINER(synth_frame) , synth_hbox );
-    synth_leftcol_vbox = gtk_vbox_new( TRUE , 0 );
-    synth_rightcol_vbox = gtk_vbox_new( FALSE , 0 );
+    synth_leftcol_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0 );
+    synth_rightcol_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0 );
     gtk_box_pack_start( GTK_BOX(synth_hbox) , synth_leftcol_vbox , TRUE , TRUE , 0 );
     gtk_box_pack_start( GTK_BOX(synth_hbox) , synth_rightcol_vbox , FALSE , FALSE , 0 );
     /* synth settings - gain */
     synth_gain_frame = gtk_frame_new( _("gain") );
     gtk_frame_set_label_align( GTK_FRAME(synth_gain_frame) , 0.5 , 0.5 );
     gtk_box_pack_start( GTK_BOX(synth_leftcol_vbox) , synth_gain_frame , TRUE , TRUE , 0 );
-    synth_gain_hbox = gtk_hbox_new( TRUE , 2 );
+    synth_gain_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2 );
     gtk_container_set_border_width( GTK_CONTAINER(synth_gain_hbox), 2 );
     gtk_container_add( GTK_CONTAINER(synth_gain_frame) , synth_gain_hbox );
     synth_gain_defcheckbt = gtk_check_button_new_with_label( _("use default") );
     gtk_box_pack_start( GTK_BOX(synth_gain_hbox) , synth_gain_defcheckbt , FALSE , FALSE , 0 );
-    synth_gain_value_hbox = gtk_hbox_new( FALSE , 4 );
+    synth_gain_value_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4 );
     synth_gain_value_label = gtk_label_new( _("value:") );
     synth_gain_value_spin = gtk_spin_button_new_with_range( 0.0 , 10.0 , 0.1 );
     gtk_spin_button_set_value( GTK_SPIN_BUTTON(synth_gain_value_spin) , 0.2 );
@@ -453,22 +425,22 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     gtk_box_pack_start( GTK_BOX(synth_gain_hbox) , synth_gain_value_hbox , FALSE , FALSE , 0 );
     gtk_box_pack_start( GTK_BOX(synth_gain_value_hbox) , synth_gain_value_label , FALSE , FALSE , 0 );
     gtk_box_pack_start( GTK_BOX(synth_gain_value_hbox) , synth_gain_value_spin , FALSE , FALSE , 0 );
-    /* synth settings - poliphony */
-    synth_poly_frame = gtk_frame_new( _("poliphony") );
+    /* synth settings - polyphony */
+    synth_poly_frame = gtk_frame_new( _("polyphony") );
     gtk_frame_set_label_align( GTK_FRAME(synth_poly_frame) , 0.5 , 0.5 );
     gtk_box_pack_start( GTK_BOX(synth_leftcol_vbox) , synth_poly_frame , TRUE , TRUE , 0 );
-    synth_poly_hbox = gtk_hbox_new( TRUE , 2 );
+    synth_poly_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2 );
     gtk_container_set_border_width( GTK_CONTAINER(synth_poly_hbox), 2 );
     gtk_container_add( GTK_CONTAINER(synth_poly_frame) , synth_poly_hbox );
     synth_poly_defcheckbt = gtk_check_button_new_with_label( _("use default") );
     gtk_box_pack_start( GTK_BOX(synth_poly_hbox) , synth_poly_defcheckbt , FALSE , FALSE , 0 );
-    synth_poly_value_hbox = gtk_hbox_new( FALSE , 4 );
+    synth_poly_value_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4 );
     synth_poly_value_label = gtk_label_new( _("value:") );
     synth_poly_value_spin = gtk_spin_button_new_with_range( 16 , 4096 , 1 );
     gtk_spin_button_set_value( GTK_SPIN_BUTTON(synth_poly_value_spin) , 256 );
     g_signal_connect( G_OBJECT(synth_poly_defcheckbt) , "toggled" ,
                       G_CALLBACK(i_configure_ev_toggle_default) , synth_poly_value_hbox );
-    if ( fsyncfg->fsyn_synth_poliphony < 0 )
+    if ( fsyncfg->fsyn_synth_polyphony < 0 )
     {
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(synth_poly_defcheckbt) , TRUE );
     }
@@ -476,7 +448,7 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     {
       gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(synth_poly_defcheckbt) , FALSE );
       gtk_spin_button_set_value( GTK_SPIN_BUTTON(synth_poly_value_spin) ,
-                                 (gdouble)fsyncfg->fsyn_synth_poliphony );
+                                 (gdouble)fsyncfg->fsyn_synth_polyphony );
     }
     gtk_box_pack_start( GTK_BOX(synth_poly_hbox) , synth_poly_value_hbox , FALSE , FALSE , 0 );
     gtk_box_pack_start( GTK_BOX(synth_poly_value_hbox) , synth_poly_value_label , FALSE , FALSE , 0 );
@@ -485,12 +457,12 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     synth_reverb_frame = gtk_frame_new( _("reverb") );
     gtk_frame_set_label_align( GTK_FRAME(synth_reverb_frame) , 0.5 , 0.5 );
     gtk_box_pack_start( GTK_BOX(synth_leftcol_vbox) , synth_reverb_frame , TRUE , TRUE , 0 );
-    synth_reverb_hbox = gtk_hbox_new( TRUE , 2 );
+    synth_reverb_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2 );
     gtk_container_set_border_width( GTK_CONTAINER(synth_reverb_hbox), 2 );
     gtk_container_add( GTK_CONTAINER(synth_reverb_frame) , synth_reverb_hbox );
     synth_reverb_defcheckbt = gtk_check_button_new_with_label( _("use default") );
     gtk_box_pack_start( GTK_BOX(synth_reverb_hbox) , synth_reverb_defcheckbt , FALSE , FALSE , 0 );
-    synth_reverb_value_hbox = gtk_hbox_new( TRUE , 4 );
+    synth_reverb_value_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4 );
     synth_reverb_value_option[0] = gtk_radio_button_new_with_label( NULL , _("yes") );
     synth_reverb_value_option[1] = gtk_radio_button_new_with_label_from_widget(
                                      GTK_RADIO_BUTTON(synth_reverb_value_option[0]) , _("no") );
@@ -516,12 +488,12 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     synth_chorus_frame = gtk_frame_new( _("chorus") );
     gtk_frame_set_label_align( GTK_FRAME(synth_chorus_frame) , 0.5 , 0.5 );
     gtk_box_pack_start( GTK_BOX(synth_leftcol_vbox) , synth_chorus_frame , TRUE , TRUE , 0 );
-    synth_chorus_hbox = gtk_hbox_new( TRUE , 2 );
+    synth_chorus_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2 );
     gtk_container_set_border_width( GTK_CONTAINER(synth_chorus_hbox), 2 );
     gtk_container_add( GTK_CONTAINER(synth_chorus_frame) , synth_chorus_hbox );
     synth_chorus_defcheckbt = gtk_check_button_new_with_label( _("use default") );
     gtk_box_pack_start( GTK_BOX(synth_chorus_hbox) , synth_chorus_defcheckbt , FALSE , FALSE , 0 );
-    synth_chorus_value_hbox = gtk_hbox_new( TRUE , 4 );
+    synth_chorus_value_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4 );
     synth_chorus_value_option[0] = gtk_radio_button_new_with_label( NULL , _("yes") );
     synth_chorus_value_option[1] = gtk_radio_button_new_with_label_from_widget(
                                      GTK_RADIO_BUTTON(synth_chorus_value_option[0]) , _("no") );
@@ -546,7 +518,7 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     /* synth settings - samplerate */
     synth_samplerate_frame = gtk_frame_new( _("sample rate") );
     gtk_frame_set_label_align( GTK_FRAME(synth_samplerate_frame) , 0.5 , 0.5 );
-    synth_samplerate_vbox = gtk_vbox_new( TRUE , 0 );
+    synth_samplerate_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0 );
     gtk_container_set_border_width( GTK_CONTAINER(synth_samplerate_vbox), 6 );
     gtk_container_add( GTK_CONTAINER(synth_samplerate_frame) , synth_samplerate_vbox );
     gtk_box_pack_start( GTK_BOX(synth_rightcol_vbox) , synth_samplerate_frame , FALSE , FALSE , 0 );
@@ -560,7 +532,7 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
     g_object_set_data( G_OBJECT(synth_samplerate_option[2]) , "val" , GINT_TO_POINTER(96000) );
     synth_samplerate_option[3] = gtk_radio_button_new_with_label_from_widget(
                                    GTK_RADIO_BUTTON(synth_samplerate_option[0]) , _("custom ") );
-    synth_samplerate_optionhbox = gtk_hbox_new( FALSE , 4 );
+    synth_samplerate_optionhbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4 );
     synth_samplerate_optionentry = gtk_entry_new();
     gtk_widget_set_sensitive( GTK_WIDGET(synth_samplerate_optionentry) , FALSE );
     gtk_entry_set_width_chars( GTK_ENTRY(synth_samplerate_optionentry) , 8 );
@@ -616,94 +588,9 @@ void i_configure_gui_tab_fsyn( GtkWidget * fsyn_page_alignment ,
                               G_CALLBACK(i_configure_ev_sychorus_commit) , synth_chorus_value_option[0] );
     g_signal_connect_swapped( G_OBJECT(commit_button) , "ap-commit" ,
                               G_CALLBACK(i_configure_ev_sysamplerate_commit) , synth_samplerate_option[3] );
-
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , soundfont_file_lv ,
-                          _("* Select SoundFont files *\n"
-                          "In order to play MIDI with FluidSynth, you need to specify at "
-                          "least one valid SoundFont file here (use absolute paths). The "
-                          "loading order is from the top (first) to the bottom (last).") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , soundfont_load_option[0] ,
-                          _("* Load SoundFont on player start *\n"
-                          "Depending on your system speed, SoundFont loading in FluidSynth will "
-                          "require up to a few seconds. This is a one-time task (the soundfont "
-                          "will stay loaded until it is changed or the backend is unloaded) that "
-                          "can be done at player start, or before the first MIDI file is played "
-                          "(the latter is a better choice if you don't use your player to listen "
-                          "MIDI files only).") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , soundfont_load_option[1] ,
-                          _("* Load SoundFont on first midifile play *\n"
-                          "Depending on your system speed, SoundFont loading in FluidSynth will "
-                          "require up to a few seconds. This is a one-time task (the soundfont "
-                          "will stay loaded until it is changed or the backend is unloaded) that "
-                          "can be done at player start, or before the first MIDI file is played "
-                          "(the latter is a better choice if you don't use your player to listen "
-                          "MIDI files only).") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_gain_value_spin ,
-                          _("* Synthesizer gain *\n"
-                          "From FluidSynth docs: the gain is applied to the final or master output "
-                          "of the synthesizer; it is set to a low value by default to avoid the "
-                          "saturation of the output when random MIDI files are played.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_poly_value_spin ,
-                          _("* Synthesizer polyphony *\n"
-                          "From FluidSynth docs: the polyphony defines how many voices can be played "
-                          "in parallel; the number of voices is not necessarily equivalent to the "
-                          "number of notes played simultaneously; indeed, when a note is struck on a "
-                          "specific MIDI channel, the preset on that channel may create several voices, "
-                          "for example, one for the left audio channel and one for the right audio "
-                          "channels; the number of voices activated depends on the number of instrument "
-                          "zones that fall in the correspond to the velocity and key of the played "
-                          "note.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_reverb_value_option[0] ,
-                          _("* Synthesizer reverb *\n"
-                          "From FluidSynth docs: when set to \"yes\" the reverb effects module is "
-                          "activated; note that when the reverb module is active, the amount of "
-                          "signal sent to the reverb module depends on the \"reverb send\" generator "
-                          "defined in the SoundFont.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_reverb_value_option[1] ,
-                          _("* Synthesizer reverb *\n"
-                          "From FluidSynth docs: when set to \"yes\" the reverb effects module is "
-                          "activated; note that when the reverb module is active, the amount of "
-                          "signal sent to the reverb module depends on the \"reverb send\" generator "
-                          "defined in the SoundFont.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_chorus_value_option[0] ,
-                          _("* Synthesizer chorus *\n"
-                          "From FluidSynth docs: when set to \"yes\" the chorus effects module is "
-                          "activated; note that when the chorus module is active, the amount of "
-                          "signal sent to the chorus module depends on the \"chorus send\" generator "
-                          "defined in the SoundFont.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_chorus_value_option[1] ,
-                          _("* Synthesizer chorus *\n"
-                          "From FluidSynth docs: when set to \"yes\" the chorus effects module is "
-                          "activated; note that when the chorus module is active, the amount of "
-                          "signal sent to the chorus module depends on the \"chorus send\" generator "
-                          "defined in the SoundFont.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_samplerate_option[0] ,
-                          _("* Synthesizer samplerate *\n"
-                          "The sample rate of the audio generated by the synthesizer. You can also specify "
-                          "a custom value in the interval 22050Hz-96000Hz.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_samplerate_option[1] ,
-                          _("* Synthesizer samplerate *\n"
-                          "The sample rate of the audio generated by the synthesizer. You can also specify "
-                          "a custom value in the interval 22050Hz-96000Hz.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_samplerate_option[2] ,
-                          _("* Synthesizer samplerate *\n"
-                          "The sample rate of the audio generated by the synthesizer. You can also specify "
-                          "a custom value in the interval 22050Hz-96000Hz.") , "" );
-    gtk_tooltips_set_tip( GTK_TOOLTIPS(tips) , synth_samplerate_option[3] ,
-                          _("* Synthesizer samplerate *\n"
-                          "The sample rate of the audio generated by the synthesizer. You can also specify "
-                          "a custom value in the interval 22050Hz-96000Hz.") , "" );
-  }
-  else
-  {
-    /* display "not available" information */
-    GtkWidget * info_label;
-    info_label = gtk_label_new( _("FluidSynth Backend not loaded or not available") );
-    gtk_box_pack_start( GTK_BOX(fsyn_page_vbox) , info_label , FALSE , FALSE , 2 );
   }
 
-  gtk_box_pack_start( GTK_BOX(fsyn_page_vbox) , content_vbox , TRUE , TRUE , 2 );
-  gtk_container_add( GTK_CONTAINER(fsyn_page_alignment) , fsyn_page_vbox );
+  gtk_container_add ((GtkContainer *) fsyn_page_alignment, content_vbox);
 }
 
 
@@ -713,7 +600,7 @@ void i_configure_gui_tablabel_fsyn( GtkWidget * fsyn_page_alignment ,
 {
   GtkWidget *pagelabel_vbox, *pagelabel_image, *pagelabel_label;
   GdkPixbuf *pagelabel_image_pix;
-  pagelabel_vbox = gtk_vbox_new( FALSE , 1 );
+  pagelabel_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1 );
   pagelabel_image_pix = gdk_pixbuf_new_from_xpm_data( (const gchar **)backend_fluidsynth_icon_xpm );
   pagelabel_image = gtk_image_new_from_pixbuf( pagelabel_image_pix ); g_object_unref( pagelabel_image_pix );
   pagelabel_label = gtk_label_new( "" );
@@ -752,7 +639,7 @@ void i_configure_cfg_fsyn_read( pcfg_t * cfgfile )
     fsyncfg->fsyn_soundfont_load = 1;
     fsyncfg->fsyn_synth_samplerate = 44100;
     fsyncfg->fsyn_synth_gain = -1;
-    fsyncfg->fsyn_synth_poliphony = -1;
+    fsyncfg->fsyn_synth_polyphony = -1;
     fsyncfg->fsyn_synth_reverb = -1;
     fsyncfg->fsyn_synth_chorus = -1;
   }
@@ -762,7 +649,7 @@ void i_configure_cfg_fsyn_read( pcfg_t * cfgfile )
     i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_soundfont_load" , &fsyncfg->fsyn_soundfont_load , 1 );
     i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_synth_samplerate" , &fsyncfg->fsyn_synth_samplerate , 44100 );
     i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_synth_gain" , &fsyncfg->fsyn_synth_gain , -1 );
-    i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_synth_poliphony" , &fsyncfg->fsyn_synth_poliphony , -1 );
+    i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_synth_polyphony" , &fsyncfg->fsyn_synth_polyphony , -1 );
     i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_synth_reverb" , &fsyncfg->fsyn_synth_reverb , -1 );
     i_pcfg_read_integer( cfgfile , "fsyn" , "fsyn_synth_chorus" , &fsyncfg->fsyn_synth_chorus , -1 );
   }
@@ -777,7 +664,9 @@ void i_configure_cfg_fsyn_save( pcfg_t * cfgfile )
   i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_soundfont_load" , fsyncfg->fsyn_soundfont_load );
   i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_synth_samplerate" , fsyncfg->fsyn_synth_samplerate );
   i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_synth_gain" , fsyncfg->fsyn_synth_gain );
-  i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_synth_poliphony" , fsyncfg->fsyn_synth_poliphony );
+  i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_synth_polyphony" , fsyncfg->fsyn_synth_polyphony );
   i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_synth_reverb" , fsyncfg->fsyn_synth_reverb );
   i_pcfg_write_integer( cfgfile , "fsyn" , "fsyn_synth_chorus" , fsyncfg->fsyn_synth_chorus );
 }
+
+#endif /* AMIDIPLUG_FLUIDSYNTH */
