@@ -18,10 +18,13 @@
 *
 */
 
+#include <gtk/gtk.h>
+
 #include <audacious/drct.h>
 #include <audacious/misc.h>
 #include <audacious/plugin.h>
 
+#include "config.h"
 #include "i_configure.h"
 #include "i_configure_private.h"
 #include "i_configure_file.h"
@@ -31,12 +34,19 @@
 #include "i_configure-fluidsynth.h"
 #include "i_utils.h"
 
+#ifdef AMIDIPLUG_ALSA
+#define DEFAULT_BACKEND "alsa"
+#elif defined AMIDIPLUG_FLUIDSYNTH
+#define DEFAULT_BACKEND "fluidsynth"
+#else
+#define DEFAULT_BACKEND ""
+#endif
+
 amidiplug_cfg_backend_t * amidiplug_cfg_backend;
 
+static void i_configure_cancel (GtkWidget * configwin);
+static void i_configure_commit (GtkWidget * configwin);
 
-void i_configure_ev_bcancel( gpointer );
-void i_configure_ev_bapply( GtkWidget * , gpointer );
-void i_configure_ev_bok( GtkWidget * , gpointer );
 void i_configure_cfg_backend_alloc( void );
 void i_configure_cfg_backend_free( void );
 void i_configure_cfg_backend_save( void );
@@ -45,30 +55,11 @@ void i_configure_cfg_ap_save( void );
 void i_configure_cfg_ap_read( void );
 
 
-GtkWidget * i_configure_gui_draw_title( gchar * title_string )
-{
-  GtkWidget *title_label, *title_evbox, *title_frame;
-  GtkStyle * style = gtk_widget_get_default_style();
-  GdkColor title_fgcol = style->fg[GTK_STATE_SELECTED];
-  GdkColor title_bgcol = style->bg[GTK_STATE_SELECTED];
-  title_label = gtk_label_new( title_string );
-  title_evbox = gtk_event_box_new();
-  title_frame = gtk_frame_new( NULL );
-  gtk_frame_set_shadow_type( GTK_FRAME(title_frame) , GTK_SHADOW_OUT );
-  gtk_container_add( GTK_CONTAINER(title_evbox) , title_label );
-  gtk_container_set_border_width( GTK_CONTAINER(title_evbox) , 5 );
-  gtk_container_add( GTK_CONTAINER(title_frame) , title_evbox );
-  gtk_widget_modify_fg( GTK_WIDGET(title_label) , GTK_STATE_NORMAL , &title_fgcol );
-  gtk_widget_modify_bg( GTK_WIDGET(title_evbox) , GTK_STATE_NORMAL , &title_bgcol );
-  return title_frame;
-}
-
-
 void i_configure_ev_browse_for_entry( GtkWidget * target_entry )
 {
   GtkWidget *parent_window = gtk_widget_get_toplevel( target_entry );
   GtkFileChooserAction act = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(target_entry),"fc-act"));
-  if ( GTK_WIDGET_TOPLEVEL(parent_window) )
+  if (gtk_widget_is_toplevel (parent_window))
   {
     GtkWidget *browse_dialog = gtk_file_chooser_dialog_new( _("AMIDI-Plug - select file") ,
                                                             GTK_WINDOW(parent_window) , act ,
@@ -88,28 +79,23 @@ void i_configure_ev_browse_for_entry( GtkWidget * target_entry )
   }
 }
 
-static void commit_cb (GtkWidget * button, void * unused)
+static void response_cb (GtkWidget * window, int response)
 {
-    if (aud_drct_get_playing ())
-        aud_drct_stop ();
+    if (response == GTK_RESPONSE_OK)
+    {
+        if (aud_drct_get_playing ())
+            aud_drct_stop ();
 
-    g_signal_emit_by_name (button, "ap-commit");
+        g_signal_emit_by_name (window, "ap-commit");
+        i_configure_commit (window);
+    }
+    else
+        i_configure_cancel (window);
 }
 
 void i_configure_gui( void )
 {
   static GtkWidget *configwin = NULL;
-  GdkGeometry cw_hints;
-  GtkWidget *configwin_vbox;
-  GtkWidget *hseparator, *hbuttonbox, *button_ok, *button_cancel, *button_apply;
-
-  GtkWidget *configwin_notebook;
-
-  GtkWidget *ap_page_alignment, *ap_pagelabel_alignment; /* amidi-plug */
-  GtkWidget *alsa_page_alignment, *alsa_pagelabel_alignment; /* alsa */
-  GtkWidget *fsyn_page_alignment, *fsyn_pagelabel_alignment; /* fluidsynth */
-
-  GSList *backend_list = NULL, *backend_list_h = NULL;
 
   if ( configwin != NULL )
   {
@@ -121,106 +107,69 @@ void i_configure_gui( void )
   i_configure_cfg_backend_alloc();
   i_configure_cfg_backend_read();
 
-  configwin = gtk_window_new( GTK_WINDOW_TOPLEVEL );
-  gtk_window_set_type_hint( GTK_WINDOW(configwin), GDK_WINDOW_TYPE_HINT_DIALOG );
-  gtk_window_set_title( GTK_WINDOW(configwin), _("AMIDI-Plug - configuration") );
-  gtk_container_set_border_width( GTK_CONTAINER(configwin), 10 );
-  g_signal_connect( G_OBJECT(configwin) , "destroy" ,
-                    G_CALLBACK(gtk_widget_destroyed) , &configwin );
-  button_ok = gtk_button_new_from_stock( GTK_STOCK_OK );
-  if ( g_signal_lookup( "ap-commit" , GTK_WIDGET_TYPE(button_ok) ) == 0 )
-  {
-    g_signal_new( "ap-commit" , GTK_WIDGET_TYPE(button_ok) ,
-                  G_SIGNAL_ACTION , 0 , NULL , NULL ,
-                  g_cclosure_marshal_VOID__VOID , G_TYPE_NONE , 0 );
-  }
+  configwin = gtk_dialog_new_with_buttons (_("AMIDI-Plug Settings"), NULL, 0,
+   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 
-  g_signal_connect (button_ok, "clicked", (GCallback) commit_cb, NULL);
+  if (! g_signal_lookup ("ap-commit", G_OBJECT_TYPE (configwin)))
+    g_signal_new ("ap-commit", G_OBJECT_TYPE (configwin), G_SIGNAL_ACTION, 0,
+     NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 
-  cw_hints.min_width = 480; cw_hints.min_height = -1;
-  gtk_window_set_geometry_hints( GTK_WINDOW(configwin) , GTK_WIDGET(configwin) ,
-                                 &cw_hints , GDK_HINT_MIN_SIZE );
+  g_signal_connect (configwin, "response", (GCallback) response_cb, NULL);
+  g_signal_connect (configwin, "destroy", (GCallback) gtk_widget_destroyed, & configwin);
 
-  configwin_vbox = gtk_vbox_new( FALSE , 0 );
-  gtk_container_add( GTK_CONTAINER(configwin) , configwin_vbox );
+  GtkWidget * configwin_vbox = gtk_dialog_get_content_area ((GtkDialog *) configwin);
 
-  configwin_notebook = gtk_notebook_new();
+  GtkWidget * configwin_notebook = gtk_notebook_new ();
   gtk_notebook_set_tab_pos( GTK_NOTEBOOK(configwin_notebook) , GTK_POS_LEFT );
   gtk_box_pack_start( GTK_BOX(configwin_vbox) , configwin_notebook , TRUE , TRUE , 2 );
 
   /* GET A LIST OF BACKENDS */
-  backend_list = i_backend_list_lookup(); /* get a list of available backends */;
-  backend_list_h = backend_list;
+  GSList * backend_list = i_backend_list_lookup ();
+  GSList * backend_list_h = backend_list;
 
   /* AMIDI-PLUG PREFERENCES TAB */
-  ap_pagelabel_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
-  ap_page_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
+  GtkWidget * ap_pagelabel_alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+  GtkWidget * ap_page_alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
   gtk_alignment_set_padding( GTK_ALIGNMENT(ap_page_alignment) , 3 , 3 , 8 , 3 );
-  i_configure_gui_tab_ap( ap_page_alignment , backend_list , button_ok );
-  i_configure_gui_tablabel_ap( ap_pagelabel_alignment , backend_list , button_ok );
+  i_configure_gui_tab_ap (ap_page_alignment, backend_list, configwin);
+  i_configure_gui_tablabel_ap (ap_pagelabel_alignment, backend_list, configwin);
   gtk_notebook_append_page( GTK_NOTEBOOK(configwin_notebook) ,
                             ap_page_alignment , ap_pagelabel_alignment );
 
+#ifdef AMIDIPLUG_ALSA
   /* ALSA BACKEND CONFIGURATION TAB */
-  alsa_pagelabel_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
-  alsa_page_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
+  GtkWidget * alsa_pagelabel_alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+  GtkWidget * alsa_page_alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
   gtk_alignment_set_padding( GTK_ALIGNMENT(alsa_page_alignment) , 3 , 3 , 8 , 3 );
-  i_configure_gui_tab_alsa( alsa_page_alignment , backend_list , button_ok );
-  i_configure_gui_tablabel_alsa( alsa_pagelabel_alignment , backend_list , button_ok );
+  i_configure_gui_tab_alsa (alsa_page_alignment, backend_list, configwin);
+  i_configure_gui_tablabel_alsa (alsa_pagelabel_alignment, backend_list, configwin);
   gtk_notebook_append_page( GTK_NOTEBOOK(configwin_notebook) ,
                             alsa_page_alignment , alsa_pagelabel_alignment );
+#endif /* AMIDIPLUG_ALSA */
 
+#if AMIDIPLUG_FLUIDSYNTH
   /* FLUIDSYNTH BACKEND CONFIGURATION TAB */
-  fsyn_pagelabel_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
-  fsyn_page_alignment = gtk_alignment_new( 0.5 , 0.5 , 1 , 1 );
+  GtkWidget * fsyn_pagelabel_alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+  GtkWidget * fsyn_page_alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
   gtk_alignment_set_padding( GTK_ALIGNMENT(fsyn_page_alignment) , 3 , 3 , 8 , 3 );
-  i_configure_gui_tab_fsyn( fsyn_page_alignment , backend_list , button_ok );
-  i_configure_gui_tablabel_fsyn( fsyn_pagelabel_alignment , backend_list , button_ok );
+  i_configure_gui_tab_fsyn (fsyn_page_alignment, backend_list, configwin);
+  i_configure_gui_tablabel_fsyn (fsyn_pagelabel_alignment, backend_list, configwin);
   gtk_notebook_append_page( GTK_NOTEBOOK(configwin_notebook) ,
                             fsyn_page_alignment , fsyn_pagelabel_alignment );
+#endif
 
   i_backend_list_free( backend_list_h ); /* done, free the list of available backends */
 
-  /* horizontal separator and buttons */
-  hseparator = gtk_hseparator_new();
-  gtk_box_pack_start( GTK_BOX(configwin_vbox) , hseparator , FALSE , FALSE , 4 );
-  hbuttonbox = gtk_hbutton_box_new();
-  gtk_button_box_set_layout( GTK_BUTTON_BOX(hbuttonbox) , GTK_BUTTONBOX_END );
-  button_apply = gtk_button_new_from_stock( GTK_STOCK_APPLY );
-  gtk_container_add( GTK_CONTAINER(hbuttonbox) , button_apply );
-  button_cancel = gtk_button_new_from_stock( GTK_STOCK_CANCEL );
-  g_signal_connect_swapped( G_OBJECT(button_cancel) , "clicked" ,
-                            G_CALLBACK(i_configure_ev_bcancel) , configwin );
-  gtk_container_add( GTK_CONTAINER(hbuttonbox) , button_cancel );
-  /* button_ok = gtk_button_new_from_stock( GTK_STOCK_OK ); created above */
-  g_object_set_data( G_OBJECT(button_ok) , "bapply_pressed" , GUINT_TO_POINTER(0) );
-  g_object_set_data( G_OBJECT(button_apply) , "bok" , button_ok );
-  g_signal_connect( G_OBJECT(button_ok) , "ap-commit" ,
-                    G_CALLBACK(i_configure_ev_bok) , configwin );
-  g_signal_connect( G_OBJECT(button_apply) , "clicked" ,
-                    G_CALLBACK(i_configure_ev_bapply) , configwin );
-  gtk_container_add( GTK_CONTAINER(hbuttonbox) , button_ok );
-  gtk_box_pack_start( GTK_BOX(configwin_vbox) , hbuttonbox , FALSE , FALSE , 0 );
-
   gtk_widget_show_all( configwin );
 }
 
-
-void i_configure_ev_bcancel( gpointer configwin )
+static void i_configure_cancel (GtkWidget * configwin)
 {
   i_configure_cfg_backend_free(); /* free backend settings */
   gtk_widget_destroy(GTK_WIDGET(configwin));
 }
 
-
-void i_configure_ev_bapply( GtkWidget * button_apply , gpointer configwin )
-{
-  GtkWidget *button_ok = g_object_get_data( G_OBJECT(button_apply) , "bok" );
-  g_object_set_data( G_OBJECT(button_ok) , "bapply_pressed" , GUINT_TO_POINTER(1) );
-  commit_cb (button_ok, NULL);
-}
-
-void i_configure_ev_bok( GtkWidget * button_ok , gpointer configwin )
+static void i_configure_commit (GtkWidget * configwin)
 {
   DEBUGMSG( "saving configuration...\n" );
   i_configure_cfg_ap_save(); /* save amidiplug settings */
@@ -244,15 +193,8 @@ void i_configure_ev_bok( GtkWidget * button_ok , gpointer configwin )
     }
   }
 
-  if ( GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(button_ok),"bapply_pressed")) == 1 )
-  {
-    g_object_set_data( G_OBJECT(button_ok) , "bapply_pressed" , GUINT_TO_POINTER(0) );
-  }
-  else
-  {
-    i_configure_cfg_backend_free(); /* free backend settings */
-    gtk_widget_destroy(GTK_WIDGET(configwin));
-  }
+  i_configure_cfg_backend_free ();
+  gtk_widget_destroy (configwin);
 }
 
 
@@ -260,15 +202,23 @@ void i_configure_cfg_backend_alloc( void )
 {
   amidiplug_cfg_backend = g_malloc(sizeof(amidiplug_cfg_backend));
 
+#ifdef AMIDIPLUG_ALSA
   i_configure_cfg_alsa_alloc(); /* alloc alsa backend configuration */
+#endif
+#ifdef AMIDIPLUG_FLUIDSYNTH
   i_configure_cfg_fsyn_alloc(); /* alloc fluidsynth backend configuration */
+#endif
 }
 
 
 void i_configure_cfg_backend_free( void )
 {
+#ifdef AMIDIPLUG_ALSA
   i_configure_cfg_alsa_free(); /* free alsa backend configuration */
+#endif
+#ifdef AMIDIPLUG_FLUIDSYNTH
   i_configure_cfg_fsyn_free(); /* free fluidsynth backend configuration */
+#endif
 
   g_free( amidiplug_cfg_backend );
 }
@@ -281,8 +231,12 @@ void i_configure_cfg_backend_read( void )
 
   cfgfile = i_pcfg_new_from_file( config_pathfilename );
 
+#ifdef AMIDIPLUG_ALSA
   i_configure_cfg_alsa_read( cfgfile ); /* get alsa backend configuration */
+#endif
+#ifdef AMIDIPLUG_FLUIDSYNTH
   i_configure_cfg_fsyn_read( cfgfile ); /* get fluidsynth backend configuration */
+#endif
 
   if ( cfgfile != NULL )
     i_pcfg_free(cfgfile);
@@ -301,8 +255,12 @@ void i_configure_cfg_backend_save( void )
   if (!cfgfile)
     cfgfile = i_pcfg_new();
 
+#ifdef AMIDIPLUG_ALSA
   i_configure_cfg_alsa_save( cfgfile ); /* save alsa backend configuration */
+#endif
+#ifdef AMIDIPLUG_FLUIDSYNTH
   i_configure_cfg_fsyn_save( cfgfile ); /* save fluidsynth backend configuration */
+#endif
 
   i_pcfg_write_to_file( cfgfile , config_pathfilename );
   i_pcfg_free( cfgfile );
@@ -321,7 +279,8 @@ void i_configure_cfg_ap_read( void )
   if (!cfgfile)
   {
     /* amidi-plug defaults */
-    amidiplug_cfg_ap.ap_seq_backend = g_strdup( "alsa" );
+
+    amidiplug_cfg_ap.ap_seq_backend = g_strdup (DEFAULT_BACKEND);
     amidiplug_cfg_ap.ap_opts_transpose_value = 0;
     amidiplug_cfg_ap.ap_opts_drumshift_value = 0;
     amidiplug_cfg_ap.ap_opts_length_precalc = 0;
@@ -330,8 +289,8 @@ void i_configure_cfg_ap_read( void )
   }
   else
   {
-    i_pcfg_read_string( cfgfile , "general" , "ap_seq_backend" ,
-                        &amidiplug_cfg_ap.ap_seq_backend , "alsa" );
+    i_pcfg_read_string ( cfgfile , "general" , "ap_seq_backend" ,
+                         &amidiplug_cfg_ap.ap_seq_backend, DEFAULT_BACKEND );
     i_pcfg_read_integer( cfgfile , "general" , "ap_opts_transpose_value" ,
                          &amidiplug_cfg_ap.ap_opts_transpose_value , 0 );
     i_pcfg_read_integer( cfgfile , "general" , "ap_opts_drumshift_value" ,
@@ -380,8 +339,5 @@ void i_configure_cfg_ap_save( void )
 
 gchar * i_configure_cfg_get_file( void )
 {
-  gchar * config_datadir = (gchar*)aud_util_get_localdir();
-  gchar * config_pathfilename = g_build_filename( config_datadir , "amidi-plug.conf" , NULL );
-  g_free( config_datadir );
-  return config_pathfilename;
+  return g_build_filename (aud_get_path (AUD_PATH_USER_DIR), "amidi-plug.conf", NULL);
 }
