@@ -18,6 +18,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses>.
  */
 
+#include <pthread.h>
 #include <string.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -25,11 +26,16 @@
 #include <cdio/cdio.h>
 #include <cdio/cdtext.h>
 #include <cdio/track.h>
-#include <cdio/cdda.h>
 #include <cdio/audio.h>
 #include <cdio/sector.h>
 #include <cdio/cd_types.h>
 
+#if LIBCDIO_VERSION_NUM >= 90
+#include <cdio/paranoia/cdda.h>
+#else
+#include <cdio/cdda.h>
+#endif
+
 /* libcdio's header files #define these */
 #undef PACKAGE
 #undef PACKAGE_BUGREPORT
@@ -75,9 +81,9 @@ typedef struct
 }
 trackinfo_t;
 
-static GMutex *mutex;
+static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
 static int seek_time;
-static bool_t stop_flag;
+static bool_t playing;
 
 /* lock mutex to read / set these variables */
 static int firsttrackno = -1;
@@ -102,11 +108,11 @@ static int calculate_track_length (int startlsn, int endlsn);
 static int find_trackno_from_filename (const char * filename);
 
 static const char cdaudio_about[] =
- "Copyright (C) 2007-2012 Calin Crisan <ccrisan@gmail.com> and others.\n\n"
- "Many thanks to libcdio developers <http://www.gnu.org/software/libcdio/>\n"
- "and to libcddb developers <http://libcddb.sourceforge.net/>.\n\n"
- "Also thank you to Tony Vroon for mentoring and guiding me.\n\n"
- "This was a Google Summer of Code 2007 project.";
+ N_("Copyright (C) 2007-2012 Calin Crisan <ccrisan@gmail.com> and others.\n\n"
+    "Many thanks to libcdio developers <http://www.gnu.org/software/libcdio/>\n"
+    "and to libcddb developers <http://libcddb.sourceforge.net/>.\n\n"
+    "Also thank you to Tony Vroon for mentoring and guiding me.\n\n"
+    "This was a Google Summer of Code 2007 project.");
 
 static const char * const schemes[] = {"cdda", NULL};
 
@@ -209,19 +215,26 @@ static void purge_all_playlists (void)
 /* main thread only */
 static bool_t monitor (gpointer unused)
 {
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
+
+    /* make sure not to close drive handle while playing */
+    if (playing)
+    {
+        pthread_mutex_unlock (& mutex);
+        return true;
+    }
 
     if (trackinfo != NULL)
         refresh_trackinfo (FALSE);
 
     if (trackinfo != NULL)
     {
-        g_mutex_unlock (mutex);
+        pthread_mutex_unlock (& mutex);
         return TRUE;
     }
 
     monitor_source = 0;
-    g_mutex_unlock (mutex);
+    pthread_mutex_unlock (& mutex);
 
     purge_all_playlists ();
     return FALSE;
@@ -237,13 +250,11 @@ static void trigger_monitor (void)
 /* main thread only */
 static bool_t cdaudio_init (void)
 {
-    mutex = g_mutex_new ();
-
     aud_config_set_defaults ("CDDA", cdaudio_defaults);
 
     if (!cdio_init ())
     {
-        cdaudio_error ("Failed to initialize cdio subsystem.");
+        cdaudio_error (_("Failed to initialize cdio subsystem."));
         return FALSE;
     }
 
@@ -263,9 +274,9 @@ static void cdaudio_set_strinfo (trackinfo_t * t,
                                  const char * performer, const char * name,
                                  const char * genre)
 {
-    g_strlcpy (t->performer, performer, DEF_STRING_LEN);
-    g_strlcpy (t->name, name, DEF_STRING_LEN);
-    g_strlcpy (t->genre, genre, DEF_STRING_LEN);
+    g_strlcpy (t->performer, performer ? performer : "", DEF_STRING_LEN);
+    g_strlcpy (t->name, name ? name : "", DEF_STRING_LEN);
+    g_strlcpy (t->genre, genre ? genre : "", DEF_STRING_LEN);
 }
 
 /* thread safe (mutex may be locked) */
@@ -283,7 +294,7 @@ static void cdaudio_set_fullinfo (trackinfo_t * t,
 static bool_t cdaudio_play (InputPlayback * p, const char * name, VFSFile *
  file, int start, int stop, bool_t pause)
 {
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
 
     if (trackinfo == NULL)
     {
@@ -291,44 +302,36 @@ static bool_t cdaudio_play (InputPlayback * p, const char * name, VFSFile *
 
         if (trackinfo == NULL)
         {
-ERR:
-            g_mutex_unlock (mutex);
+            pthread_mutex_unlock (& mutex);
             return FALSE;
         }
     }
 
+    bool_t okay = FALSE;
     int trackno = find_trackno_from_filename (name);
 
     if (trackno < 0)
-    {
-        cdaudio_error ("Invalid URI %s.", name);
-        goto ERR;
-    }
+        cdaudio_error (_("Invalid URI %s."), name);
+    else if (trackno < firsttrackno || trackno > lasttrackno)
+        cdaudio_error (_("Track %d not found."), trackno);
+    else if (! cdda_track_audiop (pcdrom_drive, trackno))
+        cdaudio_error (_("Track %d is a data track."), trackno);
+    else if (! p->output->open_audio (FMT_S16_LE, 44100, 2))
+        cdaudio_error (_("Failed to open audio output."));
+    else
+        okay = TRUE;
 
-    if (trackno < firsttrackno || trackno > lasttrackno)
+    if (! okay)
     {
-        cdaudio_error ("Track %d not found.", trackno);
-        goto ERR;
-    }
-
-    /* don't play any data tracks */
-    if (!cdda_track_audiop (pcdrom_drive, trackno))
-    {
-        cdaudio_error ("Track %d is a data track.\n", trackno);
-        goto ERR;
+        pthread_mutex_unlock (& mutex);
+        return FALSE;
     }
 
     int startlsn = trackinfo[trackno].startlsn;
     int endlsn = trackinfo[trackno].endlsn;
 
-    if (! p->output->open_audio (FMT_S16_LE, 44100, 2))
-    {
-        cdaudio_error ("Failed to open audio output.");
-        goto ERR;
-    }
-
     seek_time = (start > 0) ? start : -1;
-    stop_flag = FALSE;
+    playing = TRUE;
 
     if (stop >= 0)
         endlsn = MIN (endlsn, startlsn + stop * 75 / 1000);
@@ -339,26 +342,16 @@ ERR:
     p->set_params (p, 1411200, 44100, 2);
     p->set_pb_ready (p);
 
-    g_mutex_unlock (mutex);
-
     int buffer_size = aud_get_int (NULL, "output_buffer_size");
     int speed = aud_get_int ("CDDA", "disc_speed");
     speed = CLAMP (speed, MIN_DISC_SPEED, MAX_DISC_SPEED);
     int sectors = CLAMP (buffer_size / 2, 50, 250) * speed * 75 / 1000;
-    guchar buffer[2352 * sectors];
+    unsigned char buffer[2352 * sectors];
     int currlsn = startlsn;
     int retry_count = 0, skip_count = 0;
 
-    while (1)
+    while (playing)
     {
-        g_mutex_lock (mutex);
-
-        if (stop_flag)
-        {
-            g_mutex_unlock (mutex);
-            goto CLOSE;
-        }
-
         if (seek_time >= 0)
         {
             p->output->flush (seek_time);
@@ -366,98 +359,88 @@ ERR:
             seek_time = -1;
         }
 
-        g_mutex_unlock (mutex);
-
         sectors = MIN (sectors, endlsn + 1 - currlsn);
         if (sectors < 1)
             break;
 
-        if (cdio_read_audio_sectors (pcdrom_drive->p_cdio, buffer, currlsn, sectors) ==
-         DRIVER_OP_SUCCESS)
+        /* unlock mutex here to avoid blocking
+         * other threads must be careful not to close drive handle */
+        pthread_mutex_unlock (& mutex);
+
+        int ret = cdio_read_audio_sectors (pcdrom_drive->p_cdio, buffer,
+         currlsn, sectors);
+
+        if (ret == DRIVER_OP_SUCCESS)
+            p->output->write_audio (buffer, 2352 * sectors);
+
+        pthread_mutex_lock (& mutex);
+
+        if (ret == DRIVER_OP_SUCCESS)
         {
+            currlsn += sectors;
             retry_count = 0;
             skip_count = 0;
         }
         else if (sectors > 16)
         {
-            warn ("Read failed; reducing read size.\n");
+            /* maybe a smaller read size will help */
             sectors /= 2;
-            continue;
         }
         else if (retry_count < MAX_RETRIES)
         {
-            warn ("Read failed; retrying.\n");
+            /* still failed; retry a few times */
             retry_count ++;
-            continue;
         }
         else if (skip_count < MAX_SKIPS)
         {
-            warn ("Read failed; skipping.\n");
+            /* maybe the disk is scratched; try skipping ahead */
             currlsn = MIN (currlsn + 75, endlsn + 1);
             skip_count ++;
-            continue;
         }
         else
         {
-            cdaudio_error ("Too many read errors; giving up.");
+            /* still failed; give it up */
+            cdaudio_error (_("Error reading audio CD."));
             break;
         }
-
-        p->output->write_audio (buffer, 2352 * sectors);
-        currlsn += sectors;
     }
 
-    g_mutex_lock (mutex);
-    stop_flag = FALSE;
-    g_mutex_unlock (mutex);
+    playing = FALSE;
 
-CLOSE:
+    pthread_mutex_unlock (& mutex);
     return TRUE;
 }
 
 /* main thread only */
 static void cdaudio_stop (InputPlayback * p)
 {
-    g_mutex_lock (mutex);
-
-    if (! stop_flag)
-    {
-        stop_flag = TRUE;
-        p->output->abort_write();
-    }
-
-    g_mutex_unlock (mutex);
+    pthread_mutex_lock (& mutex);
+    playing = FALSE;
+    p->output->abort_write();
+    pthread_mutex_unlock (& mutex);
 }
 
 /* main thread only */
 static void cdaudio_pause (InputPlayback * p, bool_t pause)
 {
-    g_mutex_lock (mutex);
-
-    if (! stop_flag)
-        p->output->pause (pause);
-
-    g_mutex_unlock (mutex);
+    pthread_mutex_lock (& mutex);
+    p->output->pause (pause);
+    pthread_mutex_unlock (& mutex);
 }
 
 /* main thread only */
 static void cdaudio_mseek (InputPlayback * p, int time)
 {
-    g_mutex_lock (mutex);
-
-    if (! stop_flag)
-    {
-        seek_time = time;
-        p->output->abort_write();
-    }
-
-    g_mutex_unlock (mutex);
+    pthread_mutex_lock (& mutex);
+    seek_time = time;
+    p->output->abort_write();
+    pthread_mutex_unlock (& mutex);
 }
 
 /* main thread only */
 static void cdaudio_cleanup (void)
 {
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
 
     if (monitor_source)
     {
@@ -479,8 +462,7 @@ static void cdaudio_cleanup (void)
 
     libcddb_shutdown ();
 
-    g_mutex_unlock (mutex);
-    g_mutex_free (mutex);
+    pthread_mutex_unlock (& mutex);
 }
 
 /* thread safe */
@@ -489,7 +471,7 @@ static Tuple * make_tuple (const char * filename, VFSFile * file)
     Tuple *tuple = NULL;
     int trackno;
 
-    g_mutex_lock (mutex);
+    pthread_mutex_lock (& mutex);
 
     if (trackinfo == NULL)
         refresh_trackinfo (TRUE);
@@ -529,39 +511,21 @@ static Tuple * make_tuple (const char * filename, VFSFile * file)
 
     tuple = tuple_new_from_filename (filename);
     tuple_set_format (tuple, _("Audio CD"), 2, 44100, 1411);
-
-    if (strlen (trackinfo[trackno].performer))
-    {
-        tuple_set_str (tuple, FIELD_ARTIST, NULL,
-                                    trackinfo[trackno].performer);
-    }
-    if (strlen (trackinfo[0].name))
-    {
-        tuple_set_str (tuple, FIELD_ALBUM, NULL,
-                                    trackinfo[0].name);
-    }
-    if (strlen (trackinfo[trackno].name))
-    {
-        tuple_set_str (tuple, FIELD_TITLE, NULL,
-                                    trackinfo[trackno].name);
-    }
-
     tuple_set_int (tuple, FIELD_TRACK_NUMBER, NULL, trackno);
+    tuple_set_int (tuple, FIELD_LENGTH, NULL, calculate_track_length
+     (trackinfo[trackno].startlsn, trackinfo[trackno].endlsn));
 
-    tuple_set_int (tuple, FIELD_LENGTH, NULL,
-                             calculate_track_length (trackinfo[trackno].
-                                                     startlsn,
-                                                     trackinfo[trackno].
-                                                     endlsn));
-
-    if (strlen (trackinfo[trackno].genre))
-    {
-        tuple_set_str (tuple, FIELD_GENRE, NULL,
-                                    trackinfo[trackno].genre);
-    }
+    if (trackinfo[trackno].performer[0])
+        tuple_set_str (tuple, FIELD_ARTIST, NULL, trackinfo[trackno].performer);
+    if (trackinfo[0].name[0])
+        tuple_set_str (tuple, FIELD_ALBUM, NULL, trackinfo[0].name);
+    if (trackinfo[trackno].name[0])
+        tuple_set_str (tuple, FIELD_TITLE, NULL, trackinfo[trackno].name);
+    if (trackinfo[trackno].genre[0])
+        tuple_set_str (tuple, FIELD_GENRE, NULL, trackinfo[trackno].genre);
 
   DONE:
-    g_mutex_unlock (mutex);
+    pthread_mutex_unlock (& mutex);
     return tuple;
 }
 
@@ -576,7 +540,7 @@ static void open_cd (void)
     if (device[0])
     {
         if (! (pcdrom_drive = cdda_identify (device, 1, NULL)))
-            cdaudio_error ("Failed to open CD device %s.", device);
+            cdaudio_error (_("Failed to open CD device %s."), device);
     }
     else
     {
@@ -585,10 +549,10 @@ static void open_cd (void)
         if (ppcd_drives && ppcd_drives[0])
         {
             if (! (pcdrom_drive = cdda_identify (ppcd_drives[0], 1, NULL)))
-                cdaudio_error ("Failed to open CD device %s.", ppcd_drives[0]);
+                cdaudio_error (_("Failed to open CD device %s."), ppcd_drives[0]);
         }
         else
-            cdaudio_error ("No audio capable CD drive found.");
+            cdaudio_error (_("No audio capable CD drive found."));
 
         if (ppcd_drives)
             cdio_free_device_list (ppcd_drives);
@@ -615,7 +579,7 @@ static void scan_cd (void)
     /* finish initialization of drive/disc (performs disc TOC sanitization) */
     if (cdda_open (pcdrom_drive) != 0)
     {
-        cdaudio_error ("Failed to finish initializing opened CD drive.");
+        cdaudio_error (_("Failed to finish initializing opened CD drive."));
         goto ERR;
     }
 
@@ -628,7 +592,7 @@ static void scan_cd (void)
     lasttrackno = cdio_get_last_track_num (pcdrom_drive->p_cdio);
     if (firsttrackno == CDIO_INVALID_TRACK || lasttrackno == CDIO_INVALID_TRACK)
     {
-        cdaudio_error ("Failed to retrieve first/last track number.");
+        cdaudio_error (_("Failed to retrieve first/last track number."));
         goto ERR;
     }
     AUDDBG ("first track is %d and last track is %d\n", firsttrackno,
@@ -653,7 +617,7 @@ static void scan_cd (void)
         if (trackinfo[trackno].startlsn == CDIO_INVALID_LSN
             || trackinfo[trackno].endlsn == CDIO_INVALID_LSN)
         {
-            cdaudio_error ("Cannot read start/end LSN for track %d.", trackno);
+            cdaudio_error (_("Cannot read start/end LSN for track %d."), trackno);
             goto ERR;
         }
 
@@ -663,23 +627,32 @@ static void scan_cd (void)
     }
 
     /* get trackinfo[0] cdtext information (the disc) */
+    cdtext_t *pcdtext = NULL;
     if (aud_get_bool ("CDDA", "use_cdtext"))
     {
         AUDDBG ("getting cd-text information for disc\n");
-        cdtext_t *pcdtext = cdio_get_cdtext (pcdrom_drive->p_cdio, 0);
+#if LIBCDIO_VERSION_NUM >= 90
+        pcdtext = cdio_get_cdtext (pcdrom_drive->p_cdio);
+        if (pcdtext == NULL)
+#else
+        pcdtext = cdio_get_cdtext (pcdrom_drive->p_cdio, 0);
         if (pcdtext == NULL || pcdtext->field[CDTEXT_TITLE] == NULL)
+#endif
         {
             AUDDBG ("no cd-text available for disc\n");
         }
         else
         {
             cdaudio_set_strinfo (&trackinfo[0],
-                                 pcdtext->field[CDTEXT_PERFORMER] ? pcdtext->
-                                 field[CDTEXT_PERFORMER] : "",
-                                 pcdtext->field[CDTEXT_TITLE] ? pcdtext->
-                                 field[CDTEXT_TITLE] : "",
-                                 pcdtext->field[CDTEXT_GENRE] ? pcdtext->
-                                 field[CDTEXT_GENRE] : "");
+#if LIBCDIO_VERSION_NUM >= 90
+                                 cdtext_get(pcdtext, CDTEXT_FIELD_PERFORMER, 0),
+                                 cdtext_get(pcdtext, CDTEXT_FIELD_TITLE, 0),
+                                 cdtext_get(pcdtext, CDTEXT_FIELD_GENRE, 0));
+#else
+                                 pcdtext->field[CDTEXT_PERFORMER],
+                                 pcdtext->field[CDTEXT_TITLE],
+                                 pcdtext->field[CDTEXT_GENRE]);
+#endif
         }
     }
 
@@ -687,7 +660,7 @@ static void scan_cd (void)
     bool_t cdtext_was_available = FALSE;
     for (trackno = firsttrackno; trackno <= lasttrackno; trackno++)
     {
-        cdtext_t *pcdtext = NULL;
+#if LIBCDIO_VERSION_NUM < 90
         if (aud_get_bool ("CDDA", "use_cdtext"))
         {
             AUDDBG ("getting cd-text information for track %d\n", trackno);
@@ -698,16 +671,20 @@ static void scan_cd (void)
                 pcdtext = NULL;
             }
         }
+#endif
 
         if (pcdtext != NULL)
         {
             cdaudio_set_strinfo (&trackinfo[trackno],
-                                 pcdtext->field[CDTEXT_PERFORMER] ? pcdtext->
-                                 field[CDTEXT_PERFORMER] : "",
-                                 pcdtext->field[CDTEXT_TITLE] ? pcdtext->
-                                 field[CDTEXT_TITLE] : "",
-                                 pcdtext->field[CDTEXT_GENRE] ? pcdtext->
-                                 field[CDTEXT_GENRE] : "");
+#if LIBCDIO_VERSION_NUM >= 90
+                                 cdtext_get(pcdtext, CDTEXT_FIELD_PERFORMER, trackno),
+                                 cdtext_get(pcdtext, CDTEXT_FIELD_TITLE, trackno),
+                                 cdtext_get(pcdtext, CDTEXT_FIELD_GENRE, trackno));
+#else
+                                 pcdtext->field[CDTEXT_PERFORMER],
+                                 pcdtext->field[CDTEXT_TITLE],
+                                 pcdtext->field[CDTEXT_GENRE]);
+#endif
             cdtext_was_available = TRUE;
         }
         else
@@ -730,7 +707,7 @@ static void scan_cd (void)
         {
             pcddb_conn = cddb_new ();
             if (pcddb_conn == NULL)
-                cdaudio_error ("Failed to create the cddb connection.");
+                cdaudio_error (_("Failed to create the cddb connection."));
             else
             {
                 AUDDBG ("getting CDDB info\n");
@@ -805,9 +782,9 @@ static void scan_cd (void)
                 if ((matches = cddb_query (pcddb_conn, pcddb_disc)) == -1)
                 {
                     if (cddb_errno (pcddb_conn) == CDDB_ERR_OK)
-                        cdaudio_error ("Failed to query the CDDB server");
+                        cdaudio_error (_("Failed to query the CDDB server"));
                     else
-                        cdaudio_error ("Failed to query the CDDB server: %s",
+                        cdaudio_error (_("Failed to query the CDDB server: %s"),
                                        cddb_error_str (cddb_errno
                                                        (pcddb_conn)));
 
@@ -831,7 +808,7 @@ static void scan_cd (void)
                         cddb_read (pcddb_conn, pcddb_disc);
                         if (cddb_errno (pcddb_conn) != CDDB_ERR_OK)
                         {
-                            cdaudio_error ("failed to read the cddb info: %s",
+                            cdaudio_error (_("Failed to read the cddb info: %s"),
                                            cddb_error_str (cddb_errno
                                                            (pcddb_conn)));
                             cddb_disc_destroy (pcddb_disc);
