@@ -84,6 +84,7 @@ static GtkWidget * menu_main, * menu_rclick, * menu_tab;
 static GtkWidget * error_win = NULL;
 
 static gboolean slider_is_moving = FALSE;
+static gint slider_seek_time = -1;
 static guint delayed_title_change_source = 0;
 static guint update_song_timeout_source = 0;
 
@@ -269,6 +270,8 @@ static gboolean time_counter_cb (void)
     if (slider_is_moving)
         return TRUE;
 
+    slider_seek_time = -1;  // delayed reset to avoid seeking twice
+
     gint time = aud_drct_get_time ();
     gint length = aud_drct_get_length ();
 
@@ -296,13 +299,15 @@ static void do_seek (gint time)
     }
 }
 
-static gboolean ui_slider_change_value_cb(GtkRange * range, GtkScrollType scroll)
+static gboolean ui_slider_change_value_cb (GtkRange * range,
+ GtkScrollType scroll, gdouble value)
 {
-    gint value = gtk_range_get_value (range);
     set_time_label (value, aud_drct_get_length ());
 
-    if (!slider_is_moving)
-        do_seek (gtk_range_get_value (range));
+    if (slider_is_moving)
+        slider_seek_time = value;
+    else if ((gint) value != slider_seek_time)  // avoid seeking twice
+        do_seek (value);
 
     return FALSE;
 }
@@ -315,6 +320,9 @@ static gboolean ui_slider_button_press_cb(GtkWidget * widget, GdkEventButton * e
 
 static gboolean ui_slider_button_release_cb(GtkWidget * widget, GdkEventButton * event, gpointer user_data)
 {
+    if (slider_seek_time != -1)
+        do_seek (slider_seek_time);
+
     slider_is_moving = FALSE;
     return FALSE;
 }
@@ -737,6 +745,7 @@ static gboolean init (void)
     gtk_container_add ((GtkContainer *) boxitem1, box1);
 
     slider = gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, NULL);
+    gtk_range_set_increments ((GtkRange *) slider, 5000, 5000);
     gtk_scale_set_draw_value(GTK_SCALE(slider), FALSE);
     gtk_widget_set_size_request(slider, 120, -1);
     gtk_widget_set_valign (slider, GTK_ALIGN_CENTER);
