@@ -5,6 +5,7 @@
  */
 
 #include <fstream>
+#include <pthread.h>
 #include <stdint.h>
 #include <sys/types.h>
 #include <math.h>
@@ -14,6 +15,9 @@
 
 extern "C" {
 #include <audacious/misc.h>
+#include <audacious/i18n.h>
+
+#include "config.h"
 }
 
 #include "modplugbmp.h"
@@ -286,7 +290,7 @@ bool ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
     if(mArchive->Size() == 0)
     {
         delete mArchive;
-        return true;
+        return false;
     }
 
     if (mBuffer)
@@ -303,7 +307,7 @@ bool ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
 
     mBuffer = new unsigned char[mBufSize];
     if(!mBuffer)
-        return true;        //out of memory!
+        return false;        //out of memory!
 
     CSoundFile::SetWaveConfig
     (
@@ -373,11 +377,11 @@ bool ModplugXMMS::PlayFile(const string& aFilename, InputPlayback *ipb)
 
     if (! ipb->output->open_audio (mFormat, mModProps.mFrequency,
      mModProps.mChannels))
-        return true;
+        return false;
 
     this->PlayLoop(ipb);
 
-    return false;
+    return true;
 }
 
 void ModplugXMMS::Stop (InputPlayback * playback)
@@ -460,7 +464,7 @@ Tuple* ModplugXMMS::GetSongTuple(const string& aFilename)
     default:        tmps = "ModPlug unknown"; break;
     }
     tuple_set_str(ti, FIELD_CODEC, NULL, tmps);
-    tuple_set_str(ti, FIELD_QUALITY, NULL, "sequenced");
+    tuple_set_str(ti, FIELD_QUALITY, NULL, _("sequenced"));
     tuple_set_int(ti, FIELD_LENGTH, NULL, lSoundFile->GetSongTime() * 1000);
 
     char *tmps2 = MODPLUG_CONVERT(lSoundFile->GetTitle());
